First round of needed fixes after the overhaul
[tinc] / src / net.h
index af13036..af465f6 100644 (file)
--- a/src/net.h
+++ b/src/net.h
@@ -1,6 +1,6 @@
 /*
     net.h -- header for net.c
-    Copyright (C) 1998,99 Ivo Timmermans <zarq@iname.com>
+    Copyright (C) 1998,1999,2000 Ivo Timmermans <zarq@iname.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    $Id: net.h,v 1.9.4.11 2000/09/14 21:51:20 zarq Exp $
 */
 
 #ifndef __TINC_NET_H__
@@ -28,9 +30,6 @@
 #define MAXSIZE 1700  /* should be a bit more than the MTU for the tapdevice */
 #define MTU 1600
 
-#define MAX_PASSPHRASE_SIZE 2000 /* 2kb is really waaaay too much. nobody's
-                                   gonna need a 16 kbit passphrase */
-
 #define MAC_ADDR_S "%02x:%02x:%02x:%02x:%02x:%02x"
 #define MAC_ADDR_V(x) ((unsigned char*)&(x))[0],((unsigned char*)&(x))[1], \
                       ((unsigned char*)&(x))[2],((unsigned char*)&(x))[3], \
                       ((unsigned char*)&(x))[1],((unsigned char*)&(x))[0]
 #endif
 
+#define MAXBUFSIZE 2048 /* Probably way too much, but it must fit every possible request. */
+
+/* flags */
+#define INDIRECTDATA        0x0001 /* Used to indicate that this host has to be reached indirect */
+#define EXPORTINDIRECTDATA  0x0002 /* Used to indicate uplink that it has to tell others to do INDIRECTDATA */
+#define TCPONLY             0x0004 /* Tells sender to send packets over TCP instead of UDP (for firewalls) */
+
 typedef unsigned long ip_t;
+typedef unsigned short port_t;
 typedef short length_t;
 
+struct conn_list_t;
+
+typedef struct subnet_t {
+  ip_t netaddr;
+  ip_t netmask;
+  struct conn_list_t *owner;
+  struct subnet_t *next;
+  struct subnet_t *prev;
+} subnet_t;  
+
 typedef struct vpn_packet_t {
   length_t len;                /* the actual number of bytes in the `data' field */
   unsigned char data[MAXSIZE];
@@ -61,9 +78,8 @@ typedef struct real_packet_t {
 } real_packet_t;
 
 typedef struct passphrase_t {
-  unsigned char type;
   unsigned short len;
-  unsigned char phrase[MAX_PASSPHRASE_SIZE];
+  unsigned char *phrase;
 } passphrase_t;
 
 typedef struct status_bits_t {
@@ -78,11 +94,19 @@ typedef struct status_bits_t {
   int validkey:1;                  /* 1 if we currently have a valid key for him */
   int waitingforkey:1;             /* 1 if we already sent out a request */
   int dataopen:1;                  /* 1 if we have a valid UDP connection open */
-  int unused:22;
+  int encryptout:1;               /* 1 if we can encrypt outgoing traffic */
+  int encryptin:1;                 /* 1 if we have to decrypt incoming traffic */
+  int encrypted:1;
+  int unused:18;
 } status_bits_t;
 
+typedef struct option_bits_t {
+  int unused:32;
+} option_bits_t;
+
 typedef struct queue_element_t {
   void *packet;
+  struct queue_element_t *prev;
   struct queue_element_t *next;
 } queue_element_t;
 
@@ -98,21 +122,33 @@ typedef struct enc_key_t {
 } enc_key_t;
 
 typedef struct conn_list_t {
+  char *name;                      /* name of this connection */
   ip_t vpn_ip;                     /* his vpn ip */
   ip_t vpn_mask;                   /* his vpn network address */
   ip_t real_ip;                    /* his real (internet) ip */
-  char *hostname;                  /* the hostname of its real ip */
-  short int port;                  /* his portnumber */
+  char *hostname;             /* the hostname of its real ip */
+  short unsigned int port;         /* his portnumber */
+  int flags;                       /* his flags */
   int socket;                      /* our udp vpn socket */
   int meta_socket;                 /* our tcp meta socket */
-  unsigned char protocol_version;  /* used protocol */
+  int protocol_version;            /* used protocol */
   status_bits_t status;            /* status info */
+  option_bits_t options;           /* options turned on for this connection */
   passphrase_t *pp;                /* encoded passphrase */
   packet_queue_t *sq;              /* pending outgoing packets */
   packet_queue_t *rq;              /* pending incoming packets (they have no
                                      valid key to be decrypted with) */
   enc_key_t *public_key;           /* the other party's public key */
   enc_key_t *key;                  /* encrypt with this key */
+  char *buffer;       /* metadata input buffer */
+  int buflen;                      /* bytes read into buffer */
+  int reqlen;                      /* length of first request in buffer */
+  int tcppacket;                  /* length of incoming TCP tunnelled packet */
+  time_t last_ping_time;           /* last time we saw some activity from the other end */  
+  int want_ping;                   /* 0 if there's no need to check for activity */
+  int allow_request;               /* defined if there's only one request possible */
+  char *chal_answer;               /* answer to the given challenge */
+  enc_key_t *rsakey;
   struct conn_list_t *nexthop;     /* nearest meta-hop in this direction */
   struct conn_list_t *next;        /* after all, it's a list of connections */
 } conn_list_t;
@@ -127,13 +163,16 @@ extern int total_socket_out;
 extern conn_list_t *conn_list;
 extern conn_list_t *myself;
 
+extern char *request_name[256];
+
 extern int send_packet(ip_t, vpn_packet_t *);
-extern int send_broadcast(conn_list_t *, vpn_packet_t *);
 extern int setup_network_connections(void);
 extern void close_network_connections(void);
 extern void main_loop(void);
 extern int setup_vpn_connection(conn_list_t *);
 extern void terminate_connection(conn_list_t *);
 extern void flush_queues(conn_list_t*);
+extern int xrecv(conn_list_t *, void *);
+extern void add_queue(packet_queue_t **, void *, size_t);
 
 #endif /* __TINC_NET_H__ */